biosimulators_masspy package — BioSimulators-MASSpy 0.0.5 documentation

# biosimulators_masspy package

biosimulators_masspy.exec_sed_doc(doc, working_dir, base_out_path, rel_out_path=None, apply_xml_model_changes=True, log=None, indent=0, pretty_print_modified_xml_models=False, log_level=StandardOutputErrorCapturerLevel.c, config=None)

  Execute the tasks specified in a SED document and generate the specified outputs

  Parameters

    - doc (`SedDocument` or `str`) – SED document or a path to SED-ML file which defines a SED document

    - working_dir (`str`) – working directory of the SED document (path relative to which models are located)

    - base_out_path (`str`) –

      path to store the outputs

      - CSV: directory in which to save outputs to files `{base_out_path}/{rel_out_path}/{report.id}.csv`

      - HDF5: directory in which to save a single HDF5 file (`{base_out_path}/reports.h5`), with reports at keys `{rel_out_path}/{report.id}` within the HDF5 file

    - rel_out_path (`str`, optional) – path relative to `base_out_path` to store the outputs

    - apply_xml_model_changes (`bool`, optional) – if `True`, apply any model changes specified in the SED-ML file before calling `task_executer`.

    - log (`SedDocumentLog`, optional) – log of the document

    - indent (`int`, optional) – degree to indent status messages

    - pretty_print_modified_xml_models (`bool`, optional) – if `True`, pretty print modified XML models

    - log_level (`StandardOutputErrorCapturerLevel`, optional) – level at which to log output

    - config (`Config`, optional) – BioSimulators common configuration

    - simulator_config (`SimulatorConfig`, optional) – tellurium configuration

  Returns

    - `ReportResults`: results of each report

    - `SedDocumentLog`: log of the document

  Return type

    `tuple`

biosimulators_masspy.exec_sed_task(task, variables, preprocessed_task=None, log=None, config=None)

  Execute a task and save its results

  Parameters

    - task (`Task`) – task

    - variables (`list` of `Variable`) – variables that should be recorded

    - preprocessed_task (`dict`, optional) – preprocessed information about the task, including possible model changes and variables. This can be used to avoid repeatedly executing the same initialization for repeated calls to this method.

    - log (`TaskLog`, optional) – log for the task

    - config (`Config`, optional) – BioSimulators common configuration

  Returns

    `VariableResults`: results of variables `TaskLog`: log

  Return type

    `tuple`

  Raises

    NotImplementedError –

    - Task requires a time course that MASSpy doesn’t support * Task requires an algorithm that MASSpy doesn’t support

biosimulators_masspy.exec_sedml_docs_in_combine_archive(archive_filename, out_dir, config=None)

  Execute the SED tasks defined in a COMBINE/OMEX archive and save the outputs

  Parameters

    - archive_filename (`str`) – path to COMBINE/OMEX archive

    - out_dir (`str`) –

      path to store the outputs of the archive

      - CSV: directory in which to save outputs to files `{ out_dir }/{ relative-path-to-SED-ML-file-within-archive }/{ report.id }.csv`

      - HDF5: directory in which to save a single HDF5 file (`{ out_dir }/reports.h5`), with reports at keys `{ relative-path-to-SED-ML-file-within-archive }/{ report.id }` within the HDF5 file

    - config (`Config`, optional) – BioSimulators common configuration

  Returns

    - `SedDocumentResults`: results

    - `CombineArchiveLog`: log

  Return type

    `tuple`

biosimulators_masspy.get_simulator_version()

  Get the version of MASSpy

  Returns

    version

  Return type

    `str`

biosimulators_masspy.preprocess_sed_task(task, variables, config=None)

  Preprocess a SED task, including its possible model changes and variables. This is useful for avoiding repeatedly initializing tasks on repeated calls of `exec_sed_task`.

  Parameters

    - task (`Task`) – task

    - variables (`list` of `Variable`) – variables that should be recorded

    - config (`Config`, optional) – BioSimulators common configuration

  Returns

    preprocessed information about the task

  Return type

    `dict`

## Submodules

## biosimulators_masspy.core module

BioSimulators-compliant command-line interface to the MASSpy simulation program.

Author

  Jonathan Karr <karr@mssm.edu>

Date

  2021-08-12

Copyright

  2021, Center for Reproducible Biomedical Modeling

License

  MIT

biosimulators_masspy.core.exec_sed_doc(doc, working_dir, base_out_path, rel_out_path=None, apply_xml_model_changes=True, log=None, indent=0, pretty_print_modified_xml_models=False, log_level=StandardOutputErrorCapturerLevel.c, config=None)

  Execute the tasks specified in a SED document and generate the specified outputs

  Parameters

    - doc (`SedDocument` or `str`) – SED document or a path to SED-ML file which defines a SED document

    - working_dir (`str`) – working directory of the SED document (path relative to which models are located)

    - base_out_path (`str`) –

      path to store the outputs

      - CSV: directory in which to save outputs to files `{base_out_path}/{rel_out_path}/{report.id}.csv`

      - HDF5: directory in which to save a single HDF5 file (`{base_out_path}/reports.h5`), with reports at keys `{rel_out_path}/{report.id}` within the HDF5 file

    - rel_out_path (`str`, optional) – path relative to `base_out_path` to store the outputs

    - apply_xml_model_changes (`bool`, optional) – if `True`, apply any model changes specified in the SED-ML file before calling `task_executer`.

    - log (`SedDocumentLog`, optional) – log of the document

    - indent (`int`, optional) – degree to indent status messages

    - pretty_print_modified_xml_models (`bool`, optional) – if `True`, pretty print modified XML models

    - log_level (`StandardOutputErrorCapturerLevel`, optional) – level at which to log output

    - config (`Config`, optional) – BioSimulators common configuration

    - simulator_config (`SimulatorConfig`, optional) – tellurium configuration

  Returns

    - `ReportResults`: results of each report

    - `SedDocumentLog`: log of the document

  Return type

    `tuple`

biosimulators_masspy.core.exec_sed_task(task, variables, preprocessed_task=None, log=None, config=None)

  Execute a task and save its results

  Parameters

    - task (`Task`) – task

    - variables (`list` of `Variable`) – variables that should be recorded

    - preprocessed_task (`dict`, optional) – preprocessed information about the task, including possible model changes and variables. This can be used to avoid repeatedly executing the same initialization for repeated calls to this method.

    - log (`TaskLog`, optional) – log for the task

    - config (`Config`, optional) – BioSimulators common configuration

  Returns

    `VariableResults`: results of variables `TaskLog`: log

  Return type

    `tuple`

  Raises

    NotImplementedError –

    - Task requires a time course that MASSpy doesn’t support * Task requires an algorithm that MASSpy doesn’t support

biosimulators_masspy.core.exec_sedml_docs_in_combine_archive(archive_filename, out_dir, config=None)

  Execute the SED tasks defined in a COMBINE/OMEX archive and save the outputs

  Parameters

    - archive_filename (`str`) – path to COMBINE/OMEX archive

    - out_dir (`str`) –

      path to store the outputs of the archive

      - CSV: directory in which to save outputs to files `{ out_dir }/{ relative-path-to-SED-ML-file-within-archive }/{ report.id }.csv`

      - HDF5: directory in which to save a single HDF5 file (`{ out_dir }/reports.h5`), with reports at keys `{ relative-path-to-SED-ML-file-within-archive }/{ report.id }` within the HDF5 file

    - config (`Config`, optional) – BioSimulators common configuration

  Returns

    - `SedDocumentResults`: results

    - `CombineArchiveLog`: log

  Return type

    `tuple`

biosimulators_masspy.core.preprocess_sed_task(task, variables, config=None)

  Preprocess a SED task, including its possible model changes and variables. This is useful for avoiding repeatedly initializing tasks on repeated calls of `exec_sed_task`.

  Parameters

    - task (`Task`) – task

    - variables (`list` of `Variable`) – variables that should be recorded

    - config (`Config`, optional) – BioSimulators common configuration

  Returns

    preprocessed information about the task

  Return type

    `dict`

## biosimulators_masspy.data_model module

Data model

Author

  Jonathan Karr <karr@mssm.edu>

Date

  2021-08-12

Copyright

  2021, Center for Reproducible Biomedical Modeling

License

  MIT